---
title: <span class="badge object-type-scalar"></span> DatetimeUSNotToday
---
# <span class="badge object-type-scalar"></span> DatetimeUSNotToday

Date & time: Datetime US (No date if today)

## Definition

```python
# Date & time: Datetime US (No date if today)
DatetimeUSNotToday: typing.Literal["dateTimeAsUSNoDateIfToday"] = "dateTimeAsUSNoDateIfToday"
```
